@@ -20,6 +20,9 @@ class HonParameterFixed(HonParameter):
         super().__init__(key, attributes)
         self._value = attributes["fixedValue"]
 
+    def __repr__(self):
+        return f"{self.__class__} (<{self.key}> fixed)"
+
     @property
     def value(self):
         return self._value
@@ -40,7 +43,7 @@ class HonParameterRange(HonParameter):
         self._value = self._default
 
     def __repr__(self):
-        return f"{self.key} [{self._min} - {self._max}]"
+        return f"{self.__class__} (<{self.key}> [{self._min} - {self._max}])"
 
     @property
     def min(self):
@@ -69,12 +72,12 @@ class HonParameterRange(HonParameter):
 class HonParameterEnum(HonParameter):
     def __init__(self, key, attributes):
         super().__init__(key, attributes)
-        self._value = attributes.get("defaultValue", "0")
         self._default = attributes.get("defaultValue")
+        self._value = self._default or "0"
         self._values = attributes.get("enumValues")
 
     def __repr__(self):
-        return f"{self.key} {self._values}"
+        return f"{self.__class__} (<{self.key}> {self.values})"
 
     @property
     def values(self):
